<?php 
/*==============================================================
CONFIGURAÇÕES DO TEMPLATE
================================================================*/
function wp_theme_setup() {
	/* TAMANHO DAS IMAGENS */
	add_theme_support( 'post-thumbnails' );
	
	/* MENUS */
	register_nav_menus( array(
		'primary' => __( 'Menu Principal', 'principal' )
	) );
	
	/* SUPORTE PARA HTML5 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );
	
}
add_action( 'after_setup_theme', 'wp_theme_setup' );

/*==============================================================
ADICIONA CSS E JS
================================================================*/
function wp_add_css_js() {
	/* BIBLIOTECA JQUERY */
	wp_enqueue_script( 'jquery' );
	
	/* GOOGLE FONTS */
	wp_enqueue_style( 'googlefonts', '//fonts.googleapis.com/css?family=Roboto:400,500,700' );
	
	/* BOOTSTRAP */
	wp_enqueue_style( 'bootstrap', '//cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.min.css' );
	wp_enqueue_script( 'bootstrap', '//cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/bootstrap.min.js', array(), '3.3.7', true );
	
	/* SLICK SLIDER */
	wp_enqueue_style( 'slick', '//cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.8.1/slick.min.css' );	
	wp_enqueue_script( 'slick', '//cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.8.1/slick.min.js', array(), '1.8.1', true );
	
	/* ANIMATE CSS */
	wp_enqueue_style( 'animate', '//cdnjs.cloudflare.com/ajax/libs/animate.css/3.5.2/animate.min.css' );	
	
	/* SCIPTS DO TEMPLATE */
	wp_enqueue_script( 'scripts', get_template_directory_uri() . '/js/scripts.js', array(), '1.0.0', true );
	
	/* STYLES DO TEMAPLATE */
	wp_enqueue_style( 'styles', get_template_directory_uri() . '/css/styles.css' );	
	wp_enqueue_style( 'flaticon', get_template_directory_uri() . '/css/flaticon.css' );	
}
add_action( 'wp_enqueue_scripts', 'wp_add_css_js' );

/*==============================================================
REMOVE ITENS DO MENU ADMINISTRATIVO
================================================================*/
function remove_menus(){
	//remove_menu_page( 'index.php' );                  			//Dashboard
	//remove_menu_page( 'jetpack' );                    			//Jetpack* 
	//remove_menu_page( 'edit.php' );                   			//Posts
	//remove_menu_page( 'edit-comments.php' );          			//Comments
	//remove_menu_page( 'upload.php' );                 			//Media
	//remove_menu_page( 'edit.php?post_type=page' );    			//Pages	
	//remove_menu_page( 'themes.php' );                 			//Appearance
	//remove_menu_page( 'plugins.php' );                			//Plugins
	//remove_menu_page( 'users.php' );                  			//Users
	//remove_menu_page( 'tools.php' );                  			//Tools
	//remove_menu_page( 'options-general.php' );        			//Settings
	remove_menu_page('edit.php?post_type=acf-field-group');		//ACF 
}	
add_action( 'admin_menu', 'remove_menus' );

/*==============================================================
REMOVE ACENTOS E ESPAÇOS DOS ARQUIVOS
================================================================*/
function wp_sanitize_files ($filename) {
	return remove_accents( $filename );
}
add_filter('sanitize_file_name', 'wp_sanitize_files', 10);

/*==============================================================
EMBED RESPONSIVO
================================================================*/
function wp_embed_responsive( $html ) {
    return '<div class="video-container">' . $html . '</div>';
} 
add_filter( 'embed_oembed_html', 'wp_embed_responsive', 10, 3 );
add_filter( 'video_embed_html', 'wp_embed_responsive' );

/*==============================================================
CONTACT FORM 7
================================================================*/
add_filter( 'wpcf7_autop_or_not', '__return_false' );
add_filter('wpcf7_form_elements', function($content) {
    $content = preg_replace('/<(span).*?class="\s*(?:.*\s)?wpcf7-form-control-wrap(?:\s[^"]+)?\s*"[^\>]*>(.*)<\/\1>/i', '\2', $content);

    return $content;
});

/*==============================================================
PARAMENTROS DE VIDEOS INCORPORADOS
================================================================*/
function oembed($oembediframe) {
	$iframe = $oembediframe;
	preg_match('/src="(.+?)"/', $iframe, $matches);
	$src = $matches[1];
	$params = array(
		'rel'    	=> 0,
		'controls'  => 0,
		'showinfo'  => 0,
		'start'    => 0
	);
	$new_src = add_query_arg($params, $src);
	$iframe = str_replace($src, $new_src, $iframe);
	$attributes = 'frameborder="0" allowfullscreen';
	$iframe = str_replace('></iframe>', ' ' . $attributes . '></iframe>', $iframe);
	
	return $iframe;  	
}
function youtubeID($youtubeID) {
	$url = $youtubeID;
	parse_str( parse_url( $url, PHP_URL_QUERY ), $youtubeID );
	return $youtubeID['v'];    	
}

/*==============================================================
CONFIGURAÇÕES DO ADVANCED CUSTOM FIELDS
================================================================*/
if( function_exists('acf_add_options_page')){	
	acf_add_options_page(array(
		'page_title' 	=> 'Informações Gerais',
		'menu_title'	=> 'Informações',
		'menu_slug' 	=> 'rodape',
		'capability'	=> 'edit_posts',
		'icon_url' 		=> 'dashicons-location-alt',
		'position' 		=> 30,
		'redirect'		=> false
	));
	acf_add_options_page(array(
		'page_title' 	=> 'Slides',
		'menu_title'	=> 'Slides',
		'menu_slug' 	=> 'slides',
		'capability'	=> 'edit_posts',
		'icon_url' 		=> 'dashicons-format-gallery',
		'position' 		=> 50,
		'redirect'		=> false
	));
}

/*==============================================================
PAGINAÇÃO DO BOOTSTRAP
================================================================*/
function bootstrap_pagination( $echo = true ) {
	global $wp_query;

	$big = 999999999; // need an unlikely integer

	$pages = paginate_links( array(
			'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format' => '?paged=%#%',
			'current' => max( 1, get_query_var('paged') ),
			'total' => $wp_query->max_num_pages,
			'type'  => 'array',
			'prev_next'   => false,
			'prev_text'    => __('« Anterior'),
			'next_text'    => __('Próxima »'),
		)
	);

	if( is_array( $pages ) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');

		$pagination = '<ul class="pagination">';

		foreach ( $pages as $page ) {
			$pagination .= "<li>$page</li>";
		}

		$pagination .= '</ul>';

		if ( $echo ) {
			echo $pagination;
		} else {
			return $pagination;
		}
	}
}

/*==============================================================
RETORNA NUMEROS
================================================================*/
function sonumeros($string){
	return trim(preg_replace('#[^0-9]#', '', $string));
}

/*==============================================================
PRODUTOS
================================================================*/
function custom_post_type_produtos(){
	$labels = array(
		'name' 					=> 'Produtos',
		'singular_name' 		=> 'Produto',		
		'menu_name' 			=> 'Produtos',
		'add_new' 				=> 'Adicionar produto',
		'add_new_item' 			=> 'Adicionar novo produto',
		'new_item' 				=> 'Novo produto',
		'edit_item' 			=> 'Editar produto',
		'view_item' 			=> 'Ver produto',
		'all_items' 			=> 'Todos produtos',
		'search_items' 			=> 'Pesquisar produto',
		'not_found' 			=> 'Nenhum produto encontrado.',
		'not_found_in_trash' 	=> 'Nenhum produto encontrado na lixeira.',
	);	
	$args = array(
		'labels' 				=> $labels,
		'public' 				=> true,
		'has_archive' 			=> false,
		'query_var' 			=> true,
		'hierarchical' 			=> false,
		'supports' 				=> array('title','editor','thumbnail'),
		'capability_type' 		=> 'post',
		'menu_position' 		=> 5.2,
		'menu_icon' 			=> 'dashicons-image-filter',
		'rewrite' 				=> array( 'slug' => 'produto' ),
		'exclude_from_search' 	=> false
	);
	register_post_type('produto', $args);
}
add_action('init','custom_post_type_produtos');

/*==============================================================
CUSTOM TAXONOMY CATEGORIA
================================================================*/
add_action('init','custom_taxonomy_categorias_produtos');
function custom_taxonomy_categorias_produtos(){
	$labels = array(
		'name' 					=> 'Categorias',
		'singular_name' 		=> 'Categoria',
		'menu_name' 			=> 'Categorias',
		'all_items' 			=> 'Todas Categorias', 
		'edit_item' 			=> 'Editar Categoria', 
		'view_item' 			=> 'Ver Categoria', 
		'update_item' 			=> 'Atualizar Categoria', 
		'add_new_item' 			=> 'Adicionar Nova Categoria', 
		'new_item_name' 		=> 'Nome do Nova Categoria', 
		'parent_item' 			=> 'Pai', 
		'parent_item_colon' 	=> 'Pai', 		
		'search_item' 			=> 'Pesquisar Categoria', 
		'not_found' 			=> 'Nenhuma Categoria Encontrado'
	);
	$args = array(
		'labels' 				=> $labels,
		'capabilities' 			=> array(
									'manage_terms' => 'edit_users', 
									'edit_terms'   => 'edit_users', 
									'delete_terms' => 'edit_users', 
									'assign_terms' => 'edit_post',),
		'show_ui' 				=> true,
		'show_admin_column'		=> true,
		'query_var' 			=> true,
		'hierarchical' 			=> true, 
		'rewrite' 				=> array('slug' => 'categoria'),		
	);
	register_taxonomy('categoria', 'produto', $args);
}